@@ -2,16 +2,18 @@
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-use crate::render::prelude::*;
+use usvg::{NodeExt, TransformFromBBox};
+
+use crate::{ConvTransform, OptionLog, render::Canvas};
 
 pub fn clip(
     tree: &usvg::Tree,
     node: &usvg::Node,
     cp: &usvg::ClipPath,
-    bbox: PathBbox,
+    bbox: usvg::PathBbox,
     canvas: &mut Canvas,
-) {
-    let mut clip_pixmap = try_opt!(tiny_skia::Pixmap::new(canvas.pixmap.width(), canvas.pixmap.height()));
+) -> Option<()> {
+    let mut clip_pixmap = tiny_skia::Pixmap::new(canvas.pixmap.width(), canvas.pixmap.height())?;
     clip_pixmap.fill(tiny_skia::Color::BLACK);
 
     let mut clip_canvas = Canvas::from(clip_pixmap.as_mut());
@@ -19,8 +21,8 @@ pub fn clip(
     clip_canvas.apply_transform(cp.transform.to_native());
 
     if cp.units == usvg::Units::ObjectBoundingBox {
-        let bbox = try_opt_warn_or!(bbox.to_rect(), (),
-            "Clipping of zero-sized shapes is not allowed.");
+        let bbox = bbox.to_rect()
+            .log_none(|| log::warn!("Clipping of zero-sized shapes is not allowed."))?;
 
         clip_canvas.apply_transform(usvg::Transform::from_bbox(bbox).to_native());
     }
@@ -59,15 +61,17 @@ pub fn clip(
     paint.blend_mode = tiny_skia::BlendMode::DestinationOut;
     canvas.pixmap.draw_pixmap(0, 0, clip_pixmap.as_ref(), &paint,
                               tiny_skia::Transform::identity(), None);
+
+    Some(())
 }
 
 fn clip_group(
     tree: &usvg::Tree,
     node: &usvg::Node,
     g: &usvg::Group,
-    bbox: PathBbox,
+    bbox: usvg::PathBbox,
     canvas: &mut Canvas,
-) {
+) -> Option<()> {
     if let Some(ref id) = g.clip_path {
         if let Some(ref clip_node) = tree.defs_by_id(id) {
             if let usvg::NodeKind::ClipPath(ref cp) = *clip_node.borrow() {
@@ -75,7 +79,7 @@ fn clip_group(
                 // then we should render this child on a new canvas,
                 // clip it, and only then draw it to the `clipPath`.
 
-                let mut clip_pixmap = try_opt!(tiny_skia::Pixmap::new(canvas.pixmap.width(), canvas.pixmap.height()));
+                let mut clip_pixmap = tiny_skia::Pixmap::new(canvas.pixmap.width(), canvas.pixmap.height())?;
                 let mut clip_canvas = Canvas::from(clip_pixmap.as_mut());
                 clip_canvas.transform = canvas.transform;
 
@@ -89,6 +93,8 @@ fn clip_group(
             }
         }
     }
+
+    Some(())
 }
 
 fn draw_group_child(tree: &usvg::Tree, node: &usvg::Node, canvas: &mut Canvas) {
