@@ -2,15 +2,17 @@
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-use crate::render::prelude::*;
+use usvg::TransformFromBBox;
+
+use crate::{ConvTransform, render::{Canvas, RenderState}};
 
 pub fn mask(
     tree: &usvg::Tree,
     node: &usvg::Node,
     mask: &usvg::Mask,
-    bbox: PathBbox,
+    bbox: usvg::PathBbox,
     canvas: &mut Canvas,
-) {
+) -> Option<()> {
     let bbox = if mask.units == usvg::Units::ObjectBoundingBox ||
                   mask.content_units == usvg::Units::ObjectBoundingBox
     {
@@ -20,13 +22,13 @@ pub fn mask(
             // `objectBoundingBox` units and zero-sized bbox? Clear the canvas and return.
             // Technically a UB, but this is what Chrome and Firefox do.
             canvas.pixmap.fill(tiny_skia::Color::TRANSPARENT);
-            return;
+            return None;
         }
     } else {
-        Rect::new_bbox() // actual value doesn't matter, unreachable
+        usvg::Rect::new_bbox() // actual value doesn't matter, unreachable
     };
 
-    let mut mask_pixmap = try_opt!(tiny_skia::Pixmap::new(canvas.pixmap.width(), canvas.pixmap.height()));
+    let mut mask_pixmap = tiny_skia::Pixmap::new(canvas.pixmap.width(), canvas.pixmap.height())?;
     {
         let mut mask_canvas = Canvas::from(mask_pixmap.as_mut());
         mask_canvas.transform = canvas.transform;
@@ -77,6 +79,8 @@ pub fn mask(
         tiny_skia::Transform::identity(),
         None,
     );
+
+    Some(())
 }
 
 /// Converts an image into an alpha mask.
